from setuptools import setup, find_packages

setup(
    name='vvvip',
    version='0.3.0',
    packages=find_packages(),
    install_requires=[
 
    ],
    author='S.-W. yan',
    author_email='wq543477641@gamil.com',
    description="""Limit the number of code runs. When you pass on your project to others but do not want it to be plagiarized, you can use the vvvip library to limit the number of times others can run it. When someone modifies the access record file, it will be detected. This library can to some extent allow others to use your code a limited number of times!Author ysw""",
    license='MIT',
    keywords='Print safe money rich',
    url=''
)